#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-JLwRzaBHH8IKVToSqtNqrv
key:                  text-latin1-0.3.1-JLwRzaBHH8IKVToSqtNqrv
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  2ea582a3ca25bbe5438f1ffc583f9536
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-8.10.5/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/text-latin1-0.3.1
hs-libraries:         HStext-latin1-0.3.1-JLwRzaBHH8IKVToSqtNqrv
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    data-checked-0.3-7qMQqU9Ljdk3KKWXzaseHH
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

